==> haskell-pem-0.2.4-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pem
version: 0.2.4
id: pem-0.2.4-BcLxee31LwCG4REncAHYKL
key: pem-0.2.4-BcLxee31LwCG4REncAHYKL
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-pem
synopsis: Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description
category: Data
abi: 1a01360fc022fe0a69bfc1b290c7021b
exposed: True
exposed-modules:
    Data.PEM
hidden-modules: Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/pem-0.2.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pem
hs-libraries: HSpem-0.2.4-BcLxee31LwCG4REncAHYKL
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3=9715ac3eb77e5b1e262e646bd5991736
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
haddock-interfaces: /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html: /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pem-0.2.4-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pem
version: 0.2.4
id: pem-0.2.4-GLblkVghOyjKnlHy1vnkx7
key: pem-0.2.4-GLblkVghOyjKnlHy1vnkx7
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-pem
synopsis: Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description
category: Data
abi: 377e5889208e656e20836353a2a0101f
exposed: True
exposed-modules:
    Data.PEM
hidden-modules: Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/pem-0.2.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pem
hs-libraries: HSpem-0.2.4-GLblkVghOyjKnlHy1vnkx7
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3=9715ac3eb77e5b1e262e646bd5991736
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
haddock-interfaces: /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html: /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
